@@ -1,8 +1,7 @@
 #define QT_FEATURE_accessibility 1
 #define QT_FEATURE_action 1
-#define QT_FEATURE_opengles2 1
-#define QT_OPENGL_ES true
-#define QT_OPENGL_ES_2 true
+#define QT_FEATURE_opengles2 -1
+#define QT_FEATURE_dynamicgl -1
 #define QT_FEATURE_angle -1
 #define QT_FEATURE_clipboard 1
 #define QT_FEATURE_colornames 1
@@ -12,7 +11,6 @@
 #define QT_FEATURE_desktopservices 1
 #define QT_FEATURE_imageformat_xpm 1
 #define QT_FEATURE_draganddrop 1
-#define QT_FEATURE_dynamicgl -1
 #define QT_FEATURE_opengl 1
 #define QT_FEATURE_imageformatplugin 1
 #define QT_FEATURE_highdpiscaling 1
@@ -25,8 +23,7 @@
 #define QT_FEATURE_imageformat_ppm 1
 #define QT_FEATURE_imageformat_xbm 1
 #define QT_FEATURE_movie 1
-#define QT_FEATURE_opengles3 1
-#define QT_OPENGL_ES_3 true
+#define QT_FEATURE_opengles3 -1
 #define QT_FEATURE_opengles31 -1
 #define QT_FEATURE_openvg -1
 #define QT_FEATURE_pdf 1
@@ -40,4 +37,5 @@
 #define QT_FEATURE_texthtmlparser 1
 #define QT_FEATURE_textodfwriter 1
 #define QT_FEATURE_validator 1
+#define QT_FEATURE_whatsthis 1
 #define QT_FEATURE_wheelevent 1
